@@ -13,6 +13,7 @@ NEW_IN = {
     'bitarray':              ['2.3: optional `buffer` argument',
                               '3.4: allow initializer `bytes` or `bytearray` '
                                    'to set buffer directly'],
+    'bitarray.buffer_info':   '3.7: return named tuple',
     'bitarray.bytereverse':   '2.2.5: optional start and stop arguments',
     'bitarray.clear':         '1.4',
     'bitarray.count':        ['1.1.0: optional start and stop arguments',
@@ -25,7 +26,7 @@ NEW_IN = {
     'bitarray.find':         ['2.1',
                               '2.9: add optional keyword argument `right`'],
     'bitarray.frombytes':     '2.5.0: allow bytes-like argument',
-    'bitarray.index':        ['2.9: add optional keyword argument `right`'],
+    'bitarray.index':         '2.9: add optional keyword argument `right`',
     'bitarray.invert':        '1.5.3: optional index argument',
     'bitarray.pack':          '2.5.0: allow bytes-like argument',
     'bitarray.search':       ['2.9: optional start and stop arguments - '
@@ -51,13 +52,15 @@ NEW_IN = {
     'util.intervals':         '2.7',
     'util.ones':              '2.9',
     'util.parity':            '1.9',
-    'util.sum_indices':       '3.6',
+    'util.sum_indices':      ['3.6',
+                              '3.7: add optional mode argument'],
     'util.xor_indices':       '3.2',
     'util.pprint':            '1.8',
     'util.serialize':         '1.8',
     'util.urandom':           '1.7',
     'util.random_k':          '3.6',
     'util.random_p':          '3.5',
+    'util.gen_primes':        '3.7',
     'util.sc_encode':         '2.7',
     'util.sc_decode':         '2.7',
     'util.vl_decode':         '2.2',
@@ -102,6 +105,11 @@ NOTES = {
    memory (depending on the machine architecture) than the bitarray object,
    which may cause a memory error if the bitarray is very large.""",
 
+    'util.gen_primes': """\
+   Apart from working with prime numbers, this function is useful for
+   testing, as it provides a simple way to create a well-defined bitarray
+   of any length.""",
+
     'util.count_xor': "   This is also known as the Hamming distance."
 }
 
@@ -298,6 +306,8 @@ def main():
     testfile('./README.rst')
     for path in glob("./doc/*.rst"):
         testfile(path)
+    for path in glob("./examples/*.rst"):
+        testfile(path)
 
 
 if __name__ == '__main__':
